Module consumer

Module consumer 

Structs

ConsumerContext
Context provided to a Consumer, allowing it to send exchanges into the route.
ExchangeEnvelope
A message sent from a consumer to the route pipeline.
SecurityContext
Security context passed to a consumer before start().
StartupReceiver
Receiver half of the consumer startup handshake. Resolves once the consumer calls ConsumerContext::mark_ready (Ok) or its start() returns an Err first (Err).
StartupSignal
Shared handle used by a Consumer to signal readiness (or failure) to the runtime’s StartupReceiver.

Enums

ConcurrencyModel
How a consumer’s exchanges should be processed by the pipeline.
ConsumerStartupMode
Declares when the runtime may consider a Consumer “started”.

Traits

Consumer
A Consumer receives data from an external system and submits Exchanges to the Route’s Pipeline via the ConsumerContext.