Structs
- Consumer
Context - Context provided to a Consumer, allowing it to send exchanges into the route.
- Exchange
Envelope - A message sent from a consumer to the route pipeline.
- Security
Context - Security context passed to a consumer before
start(). - Startup
Receiver - Receiver half of the consumer startup handshake. Resolves once the
consumer calls
ConsumerContext::mark_ready(Ok) or itsstart()returns anErrfirst (Err). - Startup
Signal - Shared handle used by a Consumer to signal readiness (or failure) to the
runtime’s
StartupReceiver.
Enums
- Concurrency
Model - How a consumer’s exchanges should be processed by the pipeline.
- Consumer
Startup Mode - Declares when the runtime may consider a Consumer “started”.
Traits
- Consumer
- A Consumer receives data from an external system and submits Exchanges
to the Route’s Pipeline via the
ConsumerContext.