Module consumer

Module consumer 

Structs

ConsumerContext
Context provided to a Consumer, allowing it to send exchanges into the route.
ExchangeEnvelope
A message sent from a consumer to the route pipeline.
SecurityContext
Security context passed to a consumer before start().

Enums

ConcurrencyModel
How a consumer’s exchanges should be processed by the pipeline.

Traits

Consumer
A Consumer receives data from an external system and submits Exchanges to the Route’s Pipeline via the ConsumerContext.