Structs
- Consumer
Context - Context provided to a Consumer, allowing it to send exchanges into the route.
- Exchange
Envelope - A message sent from a consumer to the route pipeline.
- Security
Context - Security context passed to a consumer before
start().
Enums
- Concurrency
Model - How a consumer’s exchanges should be processed by the pipeline.
Traits
- Consumer
- A Consumer receives data from an external system and submits Exchanges
to the Route’s Pipeline via the
ConsumerContext.